producer

package
v0.0.0-...-293aeef Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type HTTPProducerHandler

type HTTPProducerHandler struct {
	// contains filtered or unexported fields
}

func NewHTTPProducerHandler

func NewHTTPProducerHandler(listenAddr string, produceChannel chan<- transport.Message, producerBroker *ProducerBroker) *HTTPProducerHandler

func (*HTTPProducerHandler) ServeHTTP

func (p *HTTPProducerHandler) ServeHTTP(w http.ResponseWriter, r *http.Request)

Implementing Handler interface. Refer to net/http.Handler interface.

func (*HTTPProducerHandler) Start

func (p *HTTPProducerHandler) Start() error

type ProducerBroker

type ProducerBroker struct {
	// contains filtered or unexported fields
}

func NewProducerBroker

func NewProducerBroker(loadDistributor *load.LoadDistributor) *ProducerBroker

func (*ProducerBroker) AddProducer

func (pb *ProducerBroker) AddProducer(producerChannels ...chan transport.Message) error

func (*ProducerBroker) SpawnProducerHandler

func (pb *ProducerBroker) SpawnProducerHandler(listenAddr string, producerChannels ...chan<- transport.Message) *HTTPProducerHandler

func (*ProducerBroker) Start

func (pb *ProducerBroker) Start(listenAddr string, producerChannels ...chan<- string) error

here for testing purposes only one channel is passed we have to actually pass multiple producers channels through it.

type ProducerBrokerIdentifier

type ProducerBrokerIdentifier *ProducerBroker

type ProducerHandler

type ProducerHandler interface {
	Start() error
}

Jump to