Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Consumer ¶
type Consumer struct {
Topic messagequeue.TopicIdentifier
// The websocket connection.
Conn *websocket.Conn
}
Client is a middleman between the websocket connection and the hub.
type ConsumerProxy ¶
type ConsumerProxy interface {
Start() error
}
type ConsumerRelay ¶
type WSConsumerProxy ¶
type WSConsumerProxy struct {
// contains filtered or unexported fields
}
func NewWSConsumerProxy ¶
func NewWSConsumerProxy(listenAddrs []string, consumerProxyLoadBalancerChannel chan<- *Consumer) *WSConsumerProxy
func (*WSConsumerProxy) ServeHTTP ¶
func (wscp *WSConsumerProxy) ServeHTTP(w http.ResponseWriter, r *http.Request)
func (*WSConsumerProxy) Start ¶
func (wscp *WSConsumerProxy) Start() error
type WSConsumerRelay ¶
type WSConsumerRelay struct {
// contains filtered or unexported fields
}
func NewWSConsumerRelay ¶
func NewWSConsumerRelay(storeConnector src.StoreConnector) *WSConsumerRelay
func (*WSConsumerRelay) AddConsumer ¶
func (wscr *WSConsumerRelay) AddConsumer(consumer *Consumer) bool
Adds a new connection for the messages to be relayed.
Click to show internal directories.
Click to hide internal directories.