Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
// We must use two mutex to synchronise the creation of new topic store.
ProducerAddrs []string
ConsumerAddrs []string
// contains filtered or unexported fields
}
func NewServer ¶
func NewServer(serverOpts ...ServerOption) (*Server, error)
type ServerOption ¶
type ServerOption func(*Server)
func WithConsumerAddr ¶
func WithConsumerAddr(consumerAddrs ...string) ServerOption
will update the port at 4000 only if atleast one port it given, else will keep on running at 4000 if no addr is passed.
func WithProducerAddr ¶
func WithProducerAddr(producerAddrs ...string) ServerOption
will update the port at 3000 only if atleast one port it given, else will keep on running at 3000 if no addr is passed.
Click to show internal directories.
Click to hide internal directories.